@@ -6,7 +6,7 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2025.07.13 01:00:00                  #
+# Updated Date: 2025.08.02 03:00:00                  #
 # ================================================== #
 
 import os
@@ -15,6 +15,7 @@ import io
 
 # disable warnings
 os.environ["TRANSFORMERS_NO_ADVISORY_WARNINGS"] = "1"
+os.environ["QT_LOGGING_RULES"] = "qt.multimedia.ffmpeg=false"
 
 _original_open = builtins.open
 
@@ -63,19 +64,26 @@ from pygpt_net.plugin.agent import Plugin as AgentPlugin
 from pygpt_net.plugin.mailer import Plugin as MailerPlugin
 
 # agents (Llama-index)
-from pygpt_net.provider.agents.openai import OpenAIAgent
-from pygpt_net.provider.agents.openai_assistant import OpenAIAssistantAgent
-from pygpt_net.provider.agents.planner import PlannerAgent
-from pygpt_net.provider.agents.react import ReactAgent
-from pygpt_net.provider.agents.react_workflow import ReactWorkflowAgent
-from pygpt_net.provider.agents.code_act import CodeActAgent
+from pygpt_net.provider.agents.llama_index.openai import OpenAIAgent
+from pygpt_net.provider.agents.llama_index.openai_assistant import OpenAIAssistantAgent
+from pygpt_net.provider.agents.llama_index.planner import PlannerAgent
+from pygpt_net.provider.agents.llama_index.react import ReactAgent
+from pygpt_net.provider.agents.llama_index.react_workflow import ReactWorkflowAgent
+from pygpt_net.provider.agents.llama_index.code_act import CodeActAgent
+from pygpt_net.provider.agents.openai.agent import Agent as OpenAIAgentsBase
+from pygpt_net.provider.agents.openai.agent_with_experts import Agent as OpenAIAgentsExperts
+from pygpt_net.provider.agents.openai.agent_with_experts_feedback import Agent as OpenAIAgentsExpertsFeedback
+from pygpt_net.provider.agents.openai.agent_with_feedback import Agent as OpenAIAgentFeedback
+from pygpt_net.provider.agents.openai.bot_researcher import Agent as OpenAIAgentBotResearcher
+from pygpt_net.provider.agents.openai.agent_planner import Agent as OpenAIAgentPlanner
+from pygpt_net.provider.agents.openai.evolve import Agent as OpenAIAgentsEvolve
 
 # LLM wrapper providers (langchain, llama-index, embeddings)
 from pygpt_net.provider.llms.anthropic import AnthropicLLM
 from pygpt_net.provider.llms.azure_openai import AzureOpenAILLM
 from pygpt_net.provider.llms.deepseek_api import DeepseekApiLLM
 from pygpt_net.provider.llms.google import GoogleLLM
-from pygpt_net.provider.llms.hugging_face import HuggingFaceLLM
+# from pygpt_net.provider.llms.hugging_face import HuggingFaceLLM
 from pygpt_net.provider.llms.hugging_face_api import HuggingFaceApiLLM
 from pygpt_net.provider.llms.local import LocalLLM
 from pygpt_net.provider.llms.mistral import MistralAILLM
@@ -155,13 +163,14 @@ def run(**kwargs):
     PyGPT can be extended with:
 
     - Custom plugins
-    - Custom LLM wrappers
+    - Custom LLM providers
     - Custom vector store providers
     - Custom data loaders
     - Custom audio input providers
     - Custom audio output providers
     - Custom web search engine providers
     - Custom tools
+    - Custom agents
 
     - You can pass custom plugin instances, LLM wrappers, vector store providers and more to the launcher.
     - This is useful if you want to extend PyGPT with your own plugins, vector storage, LLMs, or other data providers.
@@ -219,6 +228,7 @@ def run(**kwargs):
         from audio_output import CustomAudioOutput
         from web import CustomWebSearch
         from tools import CustomTool
+        from agents import CustomAgent
 
         plugins = [
             CustomPlugin(),
@@ -397,13 +407,20 @@ def run(**kwargs):
         for store in vector_stores:
             launcher.add_vector_store(store)
 
-    # register base llama-index agents
-    launcher.add_agent(OpenAIAgent())
-    launcher.add_agent(OpenAIAssistantAgent())
-    launcher.add_agent(PlannerAgent())
-    launcher.add_agent(ReactAgent())
-    launcher.add_agent(ReactWorkflowAgent())
-    launcher.add_agent(CodeActAgent())
+    # register base agents
+    launcher.add_agent(OpenAIAgent())  # llama-index
+    launcher.add_agent(OpenAIAssistantAgent())  # llama-index
+    launcher.add_agent(PlannerAgent())  # llama-index
+    launcher.add_agent(ReactAgent())  # llama-index
+    launcher.add_agent(ReactWorkflowAgent())  # llama-index
+    launcher.add_agent(CodeActAgent())  # llama-index
+    launcher.add_agent(OpenAIAgentsBase())  # openai-agents
+    launcher.add_agent(OpenAIAgentsExperts())  # openai-agents
+    launcher.add_agent(OpenAIAgentFeedback())  # openai-agents
+    launcher.add_agent(OpenAIAgentPlanner())  # openai-agents
+    launcher.add_agent(OpenAIAgentBotResearcher())  # openai-agents
+    launcher.add_agent(OpenAIAgentsExpertsFeedback())  # openai-agents
+    launcher.add_agent(OpenAIAgentsEvolve())  # openai-agents
 
     # register custom agents
     agents = kwargs.get('agents', None)
