@@ -6,7 +6,7 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2025.01.18 23:00:00                  #
+# Updated Date: 2025.08.03 14:00:00                  #
 # ================================================== #
 
 from typing import Optional, List, Dict, Any
@@ -14,7 +14,7 @@ from typing import Optional, List, Dict, Any
 import os
 
 from PySide6.QtCore import QTimer, Slot
-from PySide6.QtWidgets import QApplication
+from qasync import QApplication
 
 from pygpt_net.item.ctx import CtxItem
 from pygpt_net.plugin.audio_input.worker import ControlWorker
