@@ -6,7 +6,7 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2025.07.21 21:00:00                  #
+# Updated Date: 2025.07.30 00:00:00                  #
 # ================================================== #
 
 import os
@@ -18,6 +18,7 @@ from pygpt_net.core.events import Event, AppEvent, KernelEvent, RenderEvent
 from pygpt_net.core.types import (
     MODE_AGENT,
     MODE_AGENT_LLAMA,
+    MODE_AGENT_OPENAI,
     MODE_LLAMA_INDEX,
     MODE_ASSISTANT,
     MODE_IMAGE,
@@ -76,6 +77,14 @@ class Input:
                 self.window.controller.agent.common.display_infinity_loop_confirm()
                 return
 
+            # check for agent is selected
+            if mode in [MODE_AGENT_OPENAI, MODE_AGENT_LLAMA]:
+                preset = self.window.controller.presets.get_current()
+                if not preset or preset.name == "*":
+                    self.window.ui.dialogs.alert(
+                        trans("dialog.agent.not_selected"))
+                    return
+
             # check ollama model
             model = self.window.core.config.get('model')
             if model:
@@ -112,9 +121,9 @@ class Input:
 
         # agent modes
         if mode == MODE_AGENT:
-            self.window.controller.agent.legacy.on_user_send(text)  # begin legacy agent flow
-        elif mode == MODE_AGENT_LLAMA:
-            self.window.controller.agent.llama.on_user_send(text)  # begin llama agent flow
+            self.window.controller.agent.legacy.on_user_send(text)  # begin Legacy (autonomous) agent flow
+        elif mode in [MODE_AGENT_LLAMA, MODE_AGENT_OPENAI]:
+            self.window.controller.agent.llama.on_user_send(text)  # begin LlamaIndex adn OpenAI agent flow
 
         # event: user input send (manually)
         event = Event(Event.USER_SEND, {
