@@ -6,13 +6,15 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2025.07.13 01:00:00                  #
+# Updated Date: 2025.08.01 19:00:00                  #
 # ================================================== #
 
 from typing import Dict, Any
 
+from pygpt_net.core.text.utils import has_unclosed_code_tag
 from pygpt_net.core.types import (
     MODE_AGENT_LLAMA,
+    MODE_AGENT_OPENAI,
     MODE_ASSISTANT,
     MODE_CHAT,
 )
@@ -162,10 +164,15 @@ class Response:
         :param context: BridgeContext
         :param extra: Extra data
         """
+        ctx = context.ctx
         if self.window.controller.kernel.stopped():
+            output = ctx.output
+            if output and has_unclosed_code_tag(output):
+                ctx.output += "\n```"
+            self.window.core.ctx.add(ctx)  # store context to prevent current output from being lost
+            self.window.controller.ctx.prepare_name(ctx)  # summarize if not yet
             return
 
-        ctx = context.ctx
         # at first, handle previous context (user input) if not handled yet
         prev_ctx = ctx.prev_ctx
         stream = False
@@ -217,7 +224,7 @@ class Response:
         self.window.core.ctx.update_item(ctx)
 
         # update ctx meta
-        if mode == MODE_AGENT_LLAMA and ctx.meta is not None:
+        if mode in [MODE_AGENT_LLAMA, MODE_AGENT_OPENAI] and ctx.meta is not None:
             self.window.core.ctx.replace(ctx.meta)
             self.window.core.ctx.save(ctx.meta.id)
             # update preset if exists
