@@ -6,7 +6,7 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2025.07.26 18:00:00                  #
+# Updated Date: 2025.07.28 00:00:00                  #
 # ================================================== #
 
 import base64
@@ -18,6 +18,7 @@ from PySide6.QtCore import QObject, Signal, Slot, QRunnable
 from pygpt_net.core.bridge import BridgeContext
 from pygpt_net.core.events import RenderEvent
 from pygpt_net.core.types import MODE_ASSISTANT
+from pygpt_net.core.text.utils import has_unclosed_code_tag
 from pygpt_net.item.ctx import CtxItem
 
 
@@ -46,7 +47,8 @@ class StreamWorker(QObject, QRunnable):
         is_code = False
         force_func_call = False
         stopped = False
-
+        chunk_type = "raw"
+        response = None
         data = {
             "meta": self.ctx.meta,
             "ctx": self.ctx
@@ -60,34 +62,16 @@ class StreamWorker(QObject, QRunnable):
                 for chunk in self.ctx.stream:
                     # if force stop then break
                     if self.window.controller.kernel.stopped():
-                        # save current context
-                        if tool_calls:
-                            self.ctx.force_call = force_func_call
-                            self.window.core.debug.info("[chat] Tool calls found, unpacking...")
-                            self.window.core.command.unpack_tool_calls_chunks(self.ctx, tool_calls, append_output=True)
-                        # append images
-                        if is_image:
-                            self.window.core.debug.info("[chat] Image generation call found")
-                            self.ctx.images = [img_path]  # save image path to ctx
-                        self.window.core.ctx.update_item(self.ctx)  # update ctx
+                        self.ctx.msg_id = None  # reset message ID
                         stopped = True
+                        break
                     if error is not None:
-                        # save current context
-                        if tool_calls:
-                            self.ctx.force_call = force_func_call
-                            self.window.core.debug.info("[chat] Tool calls found, unpacking...")
-                            self.window.core.command.unpack_tool_calls_chunks(self.ctx, tool_calls, append_output=True)
-                        # append images
-                        if is_image:
-                            self.window.core.debug.info("[chat] Image generation call found")
-                            self.ctx.images = [img_path]  # save image path to ctx
-                        self.window.core.ctx.update_item(self.ctx)  # update ctx
+                        self.ctx.msg_id = None  # reset message ID
                         stopped = True
-                        break  # break if error
+                        break
 
                     etype = None
                     response = None
-                    chunk_type = "raw"
 
                     if self.ctx.use_responses_api:
                         if hasattr(chunk, 'type'):  # streaming event type
@@ -112,6 +96,8 @@ class StreamWorker(QObject, QRunnable):
                         elif (hasattr(chunk, 'delta')
                               and chunk.delta is not None):
                             chunk_type = "llama_chat"
+                        else:
+                            chunk_type = "raw"
 
                     # OpenAI chat completion
                     if chunk_type == "api_chat":
@@ -349,22 +335,25 @@ class StreamWorker(QObject, QRunnable):
         except Exception as e:
             error = e
 
+
+        # fix unclosed code block
+        if has_unclosed_code_tag(output):
+            output += "\n```"
+
         # update ctx
         self.ctx.output = output
         self.ctx.set_tokens(self.ctx.input_tokens, output_tokens)
         self.window.core.ctx.update_item(self.ctx)  # update ctx
 
-        if stopped:
-            return
-
         # if files from container are found, download them and append to ctx
-        if files:
+        if files and not stopped:
             self.window.core.debug.info("[chat] Container files found, downloading...")
             try:
                 self.window.core.gpt.container.download_files(self.ctx, files)
             except Exception as e:
                 self.window.core.debug.error(f"[chat] Error downloading container files: {e}")
 
+        # handle end
         self.end.emit(self.ctx)
         if error:
             self.errorOccurred.emit(error)
