@@ -6,7 +6,7 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2024.12.14 08:00:00                  #
+# Updated Date: 2025.07.19 17:00:00                  #
 # ================================================== #
 
 from typing import Optional
@@ -15,6 +15,7 @@ from PySide6.QtWidgets import QApplication
 
 from pygpt_net.core.tabs.tab import Tab
 from pygpt_net.utils import trans
+from pygpt_net.item.ctx import CtxMeta
 from .summarizer import Summarizer
 
 
@@ -89,19 +90,24 @@ class Common:
             self.window.update_status(
                 "Context duplicated, new ctx id: {}".format(new_id)
             )
-            self.window.controller.ctx.update()
+            self.window.controller.ctx.update(no_scroll=True)
 
     def dismiss_rename(self):
         """Dismiss rename dialog"""
         self.window.ui.dialog['rename'].close()
 
-    def focus_chat(self):
-        """Focus chat"""
-        tabs = self.window.ui.layout.get_active_tabs()
-        if self.window.controller.ui.tabs.get_current_type() != Tab.TAB_CHAT:
-            idx = self.window.core.tabs.get_min_idx_by_type(Tab.TAB_CHAT)
-            if idx is not None:
-                tabs.setCurrentIndex(idx)
+    def focus_chat(self, meta: CtxMeta = None):
+        """
+        Focus chat tab by meta
+
+        :param meta: CtxMeta instance
+        """
+        data_id = None
+        title = None
+        if meta:
+            data_id = meta.id
+            title = meta.name
+        self.window.controller.ui.tabs.focus_by_type(Tab.TAB_CHAT, data_id=data_id, title=title, meta=meta)
 
     def restore_display_filter(self):
         """Restore display filter"""
@@ -186,4 +192,5 @@ class Common:
             return
         self.window.core.ctx.reset_meta(meta_id)
         self.window.core.attachments.context.reset_by_meta_id(meta_id, delete_files=True)
-        self.window.controller.ctx.load(meta_id)
\ No newline at end of file
+        if self.window.core.ctx.get_current() == meta_id:
+            self.window.controller.ctx.load(meta_id)
\ No newline at end of file
