@@ -6,7 +6,7 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2025.07.19 17:00:00                  #
+# Updated Date: 2025.08.01 03:00:00                  #
 # ================================================== #
 
 import re
@@ -20,6 +20,7 @@ from pygpt_net.core.types import (
     MODE_ASSISTANT,
     MODE_CHAT,
     MODE_EXPERT,
+    MODE_AGENT_OPENAI,
 )
 from pygpt_net.controller.presets.editor import Editor
 from pygpt_net.core.events import AppEvent
@@ -43,6 +44,29 @@ class Presets:
         """Setup presets"""
         self.editor.setup()
 
+    def on_changed(self):
+        """Handle change event"""
+        pass
+
+    def is_bot(self) -> bool:
+        """
+        Check if current preset is bot
+
+        :return: True if bot
+        """
+        mode = self.window.core.config.get('mode')
+        if mode != MODE_AGENT_OPENAI:
+            return False
+        preset = self.window.core.config.get('preset')
+        if preset and preset != "*":
+            preset_data = self.window.core.presets.get_by_id(mode, preset)
+            if preset_data:
+                if preset_data.agent_openai:
+                    if (preset_data.agent_provider_openai
+                            and preset_data.agent_provider_openai.startswith("openai_agent_bot")):
+                        return True
+        return False
+
     def select(self, idx: int):
         """
         Select preset
@@ -54,12 +78,16 @@ class Presets:
             return
         mode = self.window.core.config.get('mode')
         self.set_by_idx(mode, idx)  # set global and current dict
+        preset_id = self.window.core.config.get('preset')
 
         # update all layout
         self.window.controller.ui.update()
         self.window.controller.model.select_current()
         self.window.dispatch(AppEvent(AppEvent.PRESET_SELECTED))  # app event
         self.set_selected(idx)
+        if self.window.controller.presets.editor.opened:
+            if self.window.controller.presets.editor.current != preset_id:
+                self.editor.init(preset_id)
 
     def get_current(self) -> Optional[PresetItem]:
         """
@@ -299,6 +327,9 @@ class Presets:
             self.window.ui.nodes['preset.presets'].select_by_idx(idx)
             if no_scroll:
                 self.window.ui.nodes['preset.presets'].restore_scroll_position()
+            if self.window.controller.presets.editor.opened:
+                if self.window.controller.presets.editor.current != preset_id:
+                    self.editor.init(preset_id)
 
     def select_default(self):
         """Set default preset"""
@@ -317,6 +348,9 @@ class Presets:
             else:
                 # or set default preset
                 self.window.core.config.set('preset', self.window.core.presets.get_default(mode))
+            if self.window.controller.presets.editor.opened:
+                if self.window.controller.presets.editor.current != preset_id:
+                    self.editor.init(preset_id)
 
     def update_data(self):
         """Update preset data"""
@@ -343,6 +377,7 @@ class Presets:
         self.window.core.config.set('ai_name', preset.ai_name)
         self.window.core.config.set('user_name', preset.user_name)
         self.window.core.config.set('agent.llama.provider', preset.agent_provider)
+        self.window.core.config.set('agent.openai.provider', preset.agent_provider_openai)
         self.window.core.config.set('agent.llama.idx', preset.idx)
 
     def update_current(self):
@@ -359,6 +394,7 @@ class Presets:
                 self.window.core.config.set('prompt', preset.prompt)
                 self.window.core.config.set('temperature', preset.temperature)
                 self.window.core.config.set('agent.llama.provider', preset.agent_provider)
+                self.window.core.config.set('agent.openai.provider', preset.agent_provider_openai)
                 self.window.core.config.set('agent.llama.idx', preset.idx)
                 return
 
@@ -433,6 +469,7 @@ class Presets:
         self.select_current()  # select current preset on list
         if no_scroll:
             self.window.ui.nodes['preset.presets'].restore_scroll_position()
+        self.on_changed()
 
 
     def update_list(self):
@@ -667,6 +704,7 @@ class Presets:
         :param id: preset ID
         """
         self.selected = [id] if id is not None else []
+        self.on_changed()
 
     def clear_selected(self):
         """Clear selected list"""
