@@ -6,7 +6,7 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2025.07.26 18:00:00                  #
+# Updated Date: 2025.08.02 20:00:00                  #
 # ================================================== #
 
 import copy
@@ -30,6 +30,7 @@ from pygpt_net.core.types import (
     MODE_VISION,
     MODE_RESEARCH,
     MODE_COMPUTER,
+    MODE_AGENT_OPENAI,
 )
 from pygpt_net.item.ctx import CtxItem, CtxMeta, CtxGroup
 from pygpt_net.provider.core.ctx.base import BaseProvider
@@ -81,6 +82,8 @@ class Ctx:
             MODE_ASSISTANT,
             MODE_LLAMA_INDEX,
             MODE_AGENT,
+            MODE_AGENT_LLAMA,
+            MODE_AGENT_OPENAI,
             MODE_EXPERT,
             MODE_AUDIO,
             MODE_RESEARCH,
@@ -94,12 +97,13 @@ class Ctx:
             MODE_VISION: self.all_modes,
             MODE_ASSISTANT: [MODE_ASSISTANT],
             MODE_LLAMA_INDEX: self.all_modes,
-            MODE_AGENT: self.all_modes,
             MODE_EXPERT: self.all_modes,
             MODE_AUDIO: self.all_modes,
-            MODE_AGENT_LLAMA: [MODE_AGENT_LLAMA],
+            MODE_AGENT: self.all_modes,
+            MODE_AGENT_LLAMA: self.all_modes,
+            MODE_AGENT_OPENAI: self.all_modes,
             MODE_RESEARCH: self.all_modes,
-            MODE_COMPUTER: [MODE_COMPUTER],
+            MODE_COMPUTER: self.all_modes,
         }
         self.current_sys_prompt = ""
         self.groups_loaded = False
@@ -1012,7 +1016,7 @@ class Ctx:
         for item in reversed(history_items):
             num = self.window.core.tokens.from_ctx(item, mode, model)  # get num tokens for input and output
             tokens += num
-            if tokens > max_tokens:
+            if tokens > max_tokens > 0:
                 break
             context_tokens += num
             i += 1
@@ -1048,7 +1052,7 @@ class Ctx:
                 is_first = False
                 continue
             tokens += self.window.core.tokens.from_ctx(item, mode, model)
-            if tokens > max_tokens:
+            if 0 < max_tokens < tokens:
                 break
             items.append(item)
 
