@@ -6,7 +6,7 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2025.07.22 22:00:00                  #
+# Updated Date: 2025.08.03 14:00:00                  #
 # ================================================== #
 import asyncio
 import json
@@ -20,6 +20,7 @@ from llama_index.core.tools import QueryEngineTool
 from pygpt_net.core.types import (
     MODE_CHAT,
     MODE_AGENT_LLAMA,
+    MODE_AGENT_OPENAI,
 )
 from pygpt_net.core.bridge.worker import BridgeSignals
 from pygpt_net.core.bridge.context import BridgeContext
@@ -257,7 +258,7 @@ class Chat:
         # retrieve additional context from index if tools enabled
         additional_ctx = None
         if self.window.core.config.get("llama.idx.chat.auto_retrieve", False):
-            if use_index and cmd_enabled:
+            if use_index and cmd_enabled and not ctx.internal:
                 response = self.query_retrieval(
                     query=query,
                     idx=idx,
@@ -549,7 +550,7 @@ class Chat:
             "history": history,
             "llm": llm,
         }
-        return asyncio.run(self.window.core.agents.runner.run_workflow(**kwargs))
+        return asyncio.run(self.window.core.agents.runner.llama_workflow.run(**kwargs))
 
     def is_stream_allowed(self) -> bool:
         """
@@ -897,7 +898,7 @@ class Chat:
         :param msg: message
         """
         # disabled logging for thread safety
-        if self.window.core.config.get("mode") == MODE_AGENT_LLAMA:
+        if self.window.core.config.get("mode") in [MODE_AGENT_LLAMA, MODE_AGENT_OPENAI]:
             return
         is_log = False
         if self.window.core.config.has("log.llama") \
