@@ -10,7 +10,7 @@
 # ================================================== #
 
 import datetime
-import os.path
+import os
 import time
 
 from pathlib import Path
