@@ -6,7 +6,7 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2025.07.22 22:00:00                  #
+# Updated Date: 2025.08.01 19:00:00                  #
 # ================================================== #
 
 import os
@@ -442,7 +442,14 @@ class Body:
         new QWebChannel(qt.webChannelTransport, function (channel) {
             bridge = channel.objects.bridge;
         });
-        var collapsed_idx = [];
+        let collapsed_idx = [];
+        let domOutputStream = document.getElementById('_append_output_');
+        let domOutput = document.getElementById('_output_');
+        let domInput = document.getElementById('_input_');
+        let domLastCodeBlock = null;
+        let domLastParagraphBlock = null;
+        let htmlBuffer = "";
+        
         history.scrollRestoration = "manual";
         document.addEventListener('keydown', function(event) {
             if (event.ctrlKey && event.key === 'f') {
@@ -459,6 +466,11 @@ class Body:
                 window.location.href = 'bridge://focus';
             }
         });
+        function log(text) {
+            if (bridge) {
+                bridge.log(text);
+            }
+        }
         function prepare() {        
             collapsed_idx = [];  // clear collapsed code
         }
@@ -473,11 +485,13 @@ class Body:
             });
             return doc.documentElement.outerHTML;
         }
-        function highlightCode() {
+        function highlightCode(withMath = true) {
             document.querySelectorAll('pre code').forEach(el => {
                 if (!el.classList.contains('hljs')) hljs.highlightElement(el);
             });
-            renderMath();         
+            if (withMath) {
+                renderMath();
+            }  
             restoreCollapsedCode();   
         }
         function renderMath() {
@@ -498,18 +512,9 @@ class Body:
               });
         }
         function scrollToBottom() {
+            window.scrollTo(0, document.body.scrollHeight);
+            prevScroll = document.body.scrollHeight;
             getScrollPosition();  // store using bridge
-            if (scrollTimeout !== null) {
-                return;
-            }
-            if (document.body.scrollHeight > prevScroll) {
-                scrollTimeout = setTimeout(function() {
-                    window.scrollTo(0, document.body.scrollHeight);
-                    prevScroll = document.body.scrollHeight;
-                    getScrollPosition();  // store using bridge
-                    scrollTimeout = null;
-                }, 30);
-            }
         }
         function appendToInput(content) {
             const element = document.getElementById('_append_input_');
@@ -548,6 +553,7 @@ class Body:
             scrollToBottom();
         }
         function appendNode(content) {
+            clearStreamBefore();
             prevScroll = 0;
             const element = document.getElementById('_nodes_');
             if (element) {
@@ -600,8 +606,191 @@ class Body:
             highlightCode();
             scrollToBottom();
         }
+        function getStreamContainer() {
+            let element;
+            if (domOutputStream) {
+                element = domOutputStream;
+            } else {            
+                element = document.getElementById('_append_output_');
+                if (element) {
+                    domOutputStream = element;
+                }
+            }  
+            return element;
+        }        
+        function clearStream() {
+            domLastParagraphBlock = null;
+            domLastCodeBlock = null;
+            domOutputStream = null;
+            const element = getStreamContainer();
+            let msg;
+            if (element) {
+                let box = element.querySelector('.msg-box');
+                let msg;
+                if (!box) {
+                    box = document.createElement('div');
+                    box.classList.add('msg-box');
+                    box.classList.add('msg-bot');
+                    const name = document.createElement('div');
+                    name.classList.add('name-header');
+                    name.classList.add('name-bot');
+                    name.textContent = bot_name;
+                    msg = document.createElement('div');
+                    msg.classList.add('msg');
+                    box.appendChild(name);
+                    box.appendChild(msg);
+                    element.appendChild(box);
+                } else {
+                    msg = box.querySelector('.msg');
+                }
+                if (msg) {
+                    msg.innerHTML = ''; // clear previous content
+                }
+            }
+        }
+        function beginStream() {
+            clearOutput();
+        }
+        function endStream() {
+            clearOutput();
+        }
+        function appendStream(bot_name, content, chunk, replace = false, is_code_block = false) {
+            const element = getStreamContainer();
+            doHighlight = true;
+            doMath = true;
+            let msg;
+            if (element) {
+                let box = element.querySelector('.msg-box');
+                let msg;
+                if (!box) {
+                    box = document.createElement('div');
+                    box.classList.add('msg-box');
+                    box.classList.add('msg-bot');
+                    const name = document.createElement('div');
+                    name.classList.add('name-header');
+                    name.classList.add('name-bot');
+                    name.textContent = bot_name;
+                    msg = document.createElement('div');
+                    msg.classList.add('msg');
+                    box.appendChild(name);
+                    box.appendChild(msg);
+                    element.appendChild(box);
+                } else {
+                    msg = box.querySelector('.msg');
+                }
+                if (msg) {
+                    if (replace) {
+                        msg.innerHTML = sanitize(content);
+                        domLastCodeBlock = null; // reset last code block
+                        domLastParagraphBlock = null; // reset last paragraph block
+                    } else {
+                        if (is_code_block) {
+                            let lastCodeBlock;
+                            if (domLastCodeBlock) {
+                                lastCodeBlock = domLastCodeBlock;
+                            } else {
+                                // find last code block in the message
+                                const msgBlocks = msg.querySelectorAll('pre');
+                                if (msgBlocks.length > 0) {
+                                    lastCodeBlock = msgBlocks[msgBlocks.length - 1].querySelector('code');
+                                }
+                            }
+                            if (lastCodeBlock) {
+                                // append to last code block
+                                lastCodeBlock.innerHTML += chunk;
+                                domLastCodeBlock = lastCodeBlock;
+                                doHighlight = false;
+                            } else {
+                                // if no code block, append chunk as normal text
+                                msg.innerHTML += chunk; // append chunk
+                                domLastCodeBlock = null; // reset last code block
+                            }
+                            doMath = false; // disable math rendering for code blocks
+                        } else {
+                            domLastCodeBlock = null; // reset last code block
+                            if (msg.innerHTML.trim().endsWith('</p>')) {
+                                let lastParagraphBlock;
+                                if (domLastParagraphBlock) {
+                                    lastParagraphBlock = domLastParagraphBlock;
+                                } else {
+                                    const blocksParagraph = msg.querySelectorAll('p');
+                                    if (blocksParagraph.length > 0) {
+                                        lastParagraphBlock = blocksParagraph[blocksParagraph.length - 1];
+                                    }
+                                }
+                                if (lastParagraphBlock) {
+                                    domLastParagraphBlock = lastParagraphBlock; // store last paragraph block
+                                    lastParagraphBlock.innerHTML += chunk; // append to last paragraph
+                                } else {
+                                    domLastParagraphBlock = null; // reset last paragraph block
+                                    msg.innerHTML += chunk; // append chunk
+                                }                                        
+                            } else {
+                                domLastParagraphBlock = null; // reset last paragraph block
+                                msg.innerHTML += chunk; // append chunk
+                            }
+                            doHighlight = false;
+                        }
+                    }
+                }
+            }
+            if (replace) {
+                if (doHighlight) {
+                    highlightCode(doMath);  // with or without math
+                }
+                scrollToBottom();
+            }    
+        }
         function replaceOutput(bot_name, content) {
+            const element = getStreamContainer();
+            if (element) {
+                let box = element.querySelector('.msg-box');
+                let msg;
+                if (!box) {
+                    box = document.createElement('div');
+                    box.classList.add('msg-box');
+                    box.classList.add('msg-bot');
+                    const name = document.createElement('div');
+                    name.classList.add('name-header');
+                    name.classList.add('name-bot');
+                    name.textContent = bot_name;
+                    msg = document.createElement('div');
+                    msg.classList.add('msg');
+                    box.appendChild(name);
+                    box.appendChild(msg);
+                    element.appendChild(box);
+                } else {
+                    msg = box.querySelector('.msg');
+                }
+                if (msg) {
+                    msg.innerHTML = sanitize(content);
+                }
+            }
+            highlightCode();
+            scrollToBottom();
+        }
+        function nextStream() {
+            // Clear the current stream output and copy it to the before output
+            // 1. copy current output from _append_output_ to _append_output_before_
+            // 2. clear _append_output_
             const element = document.getElementById('_append_output_');
+            const elementBefore = document.getElementById('_append_output_before_');
+            if (element && elementBefore) {
+                elementBefore.innerHTML += element.innerHTML; // append current content
+                element.innerHTML = ''; // clear current output
+                domLastCodeBlock = null; // reset last code block
+                domLastParagraphBlock = null; // reset last paragraph block
+                scrollToBottom();
+            }
+        }
+        function clearStreamBefore() {
+            const element = document.getElementById('_append_output_before_');
+            if (element) {
+                element.innerHTML = ''; // clear previous content
+            }
+        }
+        function replaceOutput(bot_name, content) {        
+            const element = getStreamContainer();
             if (element) {
                 let box = element.querySelector('.msg-box');
                 let msg;
@@ -745,6 +934,7 @@ class Body:
         }
         function clearNodes() {
             prevScroll = 0;
+            clearStreamBefore();
             const element = document.getElementById('_nodes_');
             if (element) {
                 element.textContent = '';
@@ -758,6 +948,9 @@ class Body:
             }
         }
         function clearOutput() {
+            clearStreamBefore();
+            domLastCodeBlock = null;
+            domLastParagraphBlock = null;
             const element = document.getElementById('_append_output_');
             if (element) {
                 element.textContent = '';
@@ -1009,6 +1202,7 @@ class Body:
         <div id="container">
             <div id="_nodes_" class="nodes empty_list"></div>
             <div id="_append_input_" class="append_input"></div>
+            <div id="_append_output_before_" class="append_output"></div>
             <div id="_append_output_" class="append_output"></div>            
             <div id="_append_live_" class="append_live hidden"></div>
             <div id="_footer_" class="footer"></div>
