@@ -6,7 +6,7 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2025.07.25 06:00:00                  #
+# Updated Date: 2025.08.01 19:00:00                  #
 # ================================================== #
 
 import json
@@ -46,6 +46,8 @@ class Renderer(BaseRenderer):
         self.helpers = Helpers(window)
         self.parser = Parser(window)
         self.pids = {}  # per node data
+        self.prev_chunk_replace = False
+        self.prev_chunk_newline = False
 
     def prepare(self):
         """
@@ -191,6 +193,7 @@ class Renderer(BaseRenderer):
         self.init(pid)
         self.reset_names(meta)
         self.tool_output_end()  # reset tools
+        self.prev_chunk_replace = False
 
     def end(
             self,
@@ -237,8 +240,12 @@ class Renderer(BaseRenderer):
         
         :param meta: context meta
         :param ctx: context item
-        """
-        pass
+        """        
+        self.prev_chunk_replace = False
+        try:
+            self.get_output_node(meta).page().runJavaScript("beginStream();")
+        except Exception as e:
+            pass
 
     def stream_end(
             self,
@@ -251,6 +258,7 @@ class Renderer(BaseRenderer):
         :param meta: context meta
         :param ctx: context item
         """
+        self.prev_chunk_replace = False
         pid = self.get_or_create_pid(meta)
         if pid is None:
             return
@@ -258,6 +266,10 @@ class Renderer(BaseRenderer):
             if self.pids[pid].item is not None:
                 self.append_context_item(meta, self.pids[pid].item)
                 self.pids[pid].item = None
+        try:
+            self.get_output_node(meta).page().runJavaScript("endStream();")
+        except Exception as e:
+            pass
 
     def append_context(
             self,
@@ -439,6 +451,8 @@ class Renderer(BaseRenderer):
             self.pids[pid].buffer = ""  # reset buffer
             self.pids[pid].is_cmd = False  # reset command flag
             self.clear_chunks_output(pid)
+            self.prev_chunk_replace = False
+
         self.pids[pid].buffer += raw_chunk
 
         """
@@ -452,14 +466,78 @@ class Renderer(BaseRenderer):
         """
 
         # parse chunks
-        to_append = self.pids[pid].buffer
+        buffer = self.pids[pid].buffer
         if has_unclosed_code_tag(self.pids[pid].buffer):
-            to_append += "\n```"  # fix for code block without closing ```
-        html = self.parser.parse(to_append)
-        escaped_chunk = json.dumps(html)
+            buffer += "\n```"  # fix for code block without closing ```
+        html = self.parser.parse(buffer)
+        is_code_block = html.endswith("</code></pre></div>") or html.endswith("</code></pre></div><br/>") or html.endswith("</code></pre></div><br>")
+        is_newline = "\n" in raw_chunk or buffer.endswith("\n") or is_code_block
+        force_replace = False
+        if self.prev_chunk_newline:
+            force_replace = True
+        if "\n" in raw_chunk:
+            self.prev_chunk_newline = True
+        else:
+            self.prev_chunk_newline = False
+        replace = "false"
+        if is_newline or force_replace:
+            replace = "true"
+            if is_code_block:
+                # don't replace if it is a code block
+                if "\n" not in raw_chunk:
+                    # if there is no newline in raw_chunk, then don't replace
+                    replace = "false"
+            if replace == "true":
+                pass
+                #html += "<br/>"  # add line break at the end
+
+       # print('[' + raw_chunk + ']', '[' + html + ']', replace)
+
+        # if prev replace and current code block then add \n to chunk
+        code_block_arg = "false"
+        if is_code_block:
+            code_block_arg = "true"
+        if not is_code_block:
+            raw_chunk = raw_chunk.replace("\n", "<br/>")
+            pass
+        else:
+            if self.prev_chunk_replace and not has_unclosed_code_tag(raw_chunk):
+                # if previous chunk was replaced and current is code block, then add \n to chunk
+                raw_chunk = "\n" + raw_chunk  # add newline to chunk
+        escaped_chunk = json.dumps(raw_chunk)
+        escaped_buffer = json.dumps(html)
+
+        if replace == "true":
+            self.prev_chunk_replace = True
+        else:
+            self.prev_chunk_replace = False
+
         try:
             self.get_output_node(meta).page().runJavaScript(
-                f"replaceOutput('{self.pids[pid].name_bot}', {escaped_chunk});")
+                f"appendStream('{self.pids[pid].name_bot}', {escaped_buffer}, {escaped_chunk}, {replace}, {code_block_arg});")
+        except Exception as e:
+            pass
+
+    def next_chunk(
+            self,
+            meta: CtxMeta,
+            ctx: CtxItem,
+    ):
+        """
+        Flush current stream and start with new chunks
+
+        :param meta: context meta
+        :param ctx: context item
+        """
+        pid = self.get_or_create_pid(meta)
+        self.pids[pid].item = ctx
+        self.pids[pid].buffer = ""  # always reset buffer
+        self.update_names(meta, ctx)
+        self.prev_chunk_replace = False
+        self.prev_chunk_newline = False
+        try:
+            self.get_output_node(meta).page().runJavaScript(
+                f"nextStream();")
         except Exception as e:
             pass
 
@@ -816,6 +894,7 @@ class Renderer(BaseRenderer):
         self.pids[pid].files_appended = []
         self.get_output_node_by_pid(pid).reset_current_content()
         self.reset_names_by_pid(pid)
+        self.prev_chunk_replace = False
 
     def clear_input(self):
         """Clear input"""
@@ -830,6 +909,7 @@ class Renderer(BaseRenderer):
 
         :param meta: Context meta
         """
+        self.prev_chunk_replace = False
         self.reset(meta)
 
     def clear_chunks(self, pid):
@@ -873,6 +953,7 @@ class Renderer(BaseRenderer):
 
         :pid: context PID
         """
+        self.prev_chunk_replace = False
         if not self.pids[pid].loaded:
             js = "var element = document.getElementById('_append_output_');"
             js += "if (element) { element.innerHTML = ''; }"
