@@ -6,12 +6,12 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2025.01.19 02:00:00                  #
+# Updated Date: 2025.07.20 23:00:00                  #
 # ================================================== #
 
 import uuid
 from datetime import datetime
-from typing import Optional, Any, Dict
+from typing import Optional, Any, Dict, Tuple
 
 from PySide6.QtGui import QIcon
 from PySide6.QtWidgets import QVBoxLayout, QWidget, QLayout
@@ -286,6 +286,7 @@ class Tabs:
         """Remove all tabs"""
         for pid in list(self.pids):
             self.remove(pid)  # delete from PIDs and UI
+        self.pids = {}
         self.window.core.ctx.output.clear()  # clear mapping
 
     def remove_all_by_type(
@@ -419,6 +420,31 @@ class Tabs:
                 min = tab.idx
         return min
 
+    def get_min_idx_by_type_exists(
+            self,
+            type: int,
+            column_idx: int = 0
+    ) -> Tuple[int, int, bool]:
+        """
+        Get min index by type
+
+        :param type: Tab type
+        :param column_idx: Column index
+        :return: Min index
+        """
+        min = 999999
+        column_idx = None
+        exists = False
+        for pid in self.pids:
+            tab = self.pids[pid]
+            if (tab.type == type
+                    and tab.column_idx == column_idx
+                    and tab.idx < min):
+                min = tab.idx
+                exists = True
+                column_idx = tab.column_idx
+        return min, column_idx, exists
+
     def update(self):
         """Update tabs data (pids) from UI (all columns)"""
         for n in range(0, self.NUM_COLS):
@@ -719,13 +745,18 @@ class Tabs:
         data = {}
         for pid in self.pids:
             tab = self.pids[pid]
+            title = tab.title
+            if title is None:
+                title = ""
+            if title.startswith("[i:"):
+                title = title.split("] ", 1)[-1]  # remove debug info
             data[pid] = {
                 "uuid": str(tab.uuid),
                 "pid": tab.pid,
                 "idx": tab.idx,
                 "type": tab.type,
                 "data_id": tab.data_id,
-                "title": tab.title,
+                "title": title,
                 "tooltip": tab.tooltip,
                 "custom_name": tab.custom_name,
                 "column_idx": tab.column_idx,
@@ -796,6 +827,37 @@ class Tabs:
                 tabs.setTabToolTip(tab.idx, tab.title)
                 processed.append(pid)
 
+    def toggle_debug(self, enabled: bool = False):
+        """
+        Toggle debug mode for all tabs
+
+        :param enabled: Enable debug mode
+        """
+        for column_idx in range(0, self.NUM_COLS):
+            tabs = self.window.ui.layout.get_tabs_by_idx(column_idx)
+            for idx in range(tabs.count()):
+                tab = self.get_tab_by_index(idx, column_idx)
+                if tab is None:
+                    continue
+                title = tab.title  # remove prev debug from all [...], using regex
+                if title.startswith("[i:"):
+                    title = title.split("] ", 1)[-1]  # remove debug info
+                if enabled:
+                    debug_info = f"[i: {tab.idx}, p: {tab.pid}"
+                    if tab.data_id is not None:
+                        debug_info += f", d: {tab.data_id}"
+                    debug_info += f", c: {tab.column_idx}] {title}"
+                    tabs.setTabText(idx, debug_info)
+                    tabs.setTabToolTip(idx, tab.tooltip)
+                else:
+                    tabs.setTabText(idx, title)
+                    if tab.tooltip is not None:
+                        tabs.setTabToolTip(idx, tab.tooltip)
+                    else:
+                        tabs.setTabToolTip(idx, "")
+        if not enabled:
+            self.save()
+
     def from_widget(self, widget: QWidget) -> TabBody:
         """
         Prepare tab body from widget
