@@ -6,9 +6,11 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2025.07.01 01:00:00                  #
+# Updated Date: 2025.07.13 01:00:00                  #
 # ================================================== #
 
+from .agent import *
 from .mode import *
+from .model import *
 from .openai import *
 from .multimodal import *
\ No newline at end of file
