@@ -6,7 +6,7 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2024.12.16 01:00:00                  #
+# Updated Date: 2025.06.23 19:00:00                  #
 # ================================================== #
 
 import json
@@ -43,7 +43,7 @@ class AttachmentItem:
         """
         return {
             'id': self.id,
-            'uuid': self.uuid,
+            'uuid': str(self.uuid),
             'name': self.name,
             'path': self.path,
             'size': self.size,
