@@ -89,6 +89,7 @@ class CtxItem:
         self.bag = None
         self.live_output = ""
         self.force_call = False  # force call even if command is not present
+        self.partial = False  # not final output, used in cycle next ctx, force wait for final output, do not eval, etc
 
 
     @property
@@ -357,6 +358,15 @@ class CtxItem:
             pass
         return ""
 
+    def print(self):
+        """Print context item"""
+        print("\n----------------------------")
+        print("[" + str(self.id) + "]")
+        print("Input:", self.input)
+        print("Output:", self.output)
+        print("Extra:", self.extra)
+        print("\n-----------------------------")
+
     def __str__(self):
         """To string"""
         return self.dump(True)
