@@ -6,12 +6,14 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2024.11.25 02:00:00                  #
+# Updated Date: 2025.07.17 19:00:00                  #
 # ================================================== #
-
+import base64
 import os
 import json
 import re
+import time
+
 import docker
 import io
 import tarfile
@@ -20,6 +22,9 @@ from jupyter_client import BlockingKernelClient
 from docker.errors import DockerException
 
 class DockerKernel:
+
+    NOT_READY_MSG = "IPython kernel is not initialized... try to restart the kernel with: /restart"
+
     def __init__(self, plugin = None):
         self.plugin = plugin
         self.kernel_file = ".interpreter.kernel.json"
@@ -38,6 +43,8 @@ class DockerKernel:
             "hb": 5559,
         }
         self.signals = None
+        self.restarting = False
+        self.allow_auto_restart = True
 
     def get_dockerfile(self) -> str:
         """
@@ -115,24 +122,46 @@ class DockerKernel:
             if 'stream' in chunk:
                 self.log(chunk['stream'].strip())
 
-    def init(self, force: bool = False):
+    def init(
+            self,
+            force: bool = False,
+            auto_init: bool = False) -> None:
         """
         Initialize the IPython kernel client.
 
         :param force: Force reinitialization.
+        :param auto_init: Automatically initialize the kernel if not initialized after error.
         """
         if self.initialized and not force:
             return
+
         self.prepare_local_data_dir()
         self.start_container(self.get_container_name())
         self.prepare_conn()
         self.client = BlockingKernelClient(connection_file=self.get_kernel_file_path())
         self.client.load_connection_file()
         self.client.start_channels()
-        self.client.wait_for_ready()
+
+        try:
+            self.client.wait_for_ready()
+        except RuntimeError as e:
+            print(e)
+            self.log(f"Error connecting to IPython kernel: {e}")
+            self.initialized = False
+
+            # try to restart the container if auto-restart is allowed
+            if self.allow_auto_restart:
+                self.allow_auto_restart = False  # Disable auto-restart again to prevent infinite loop
+                self.log("Trying to auto-restart the container...")
+                self.restart()
+                if auto_init:
+                    self.init()
+            return
+
         self.log("Connected to IPython kernel.")
         self.initialized = True
         self.log("IPython kernel is ready.")
+        self.allow_auto_restart = True  # Re-enable auto-restart after successful connection
 
     def prepare_local_data_dir(self):
         """
@@ -156,11 +185,11 @@ class DockerKernel:
         """Prepare the connection file."""
         ports = self.get_ports()
         conn = {
-            "shell_port": ports["shell"],
-            "iopub_port": ports["iopub"],
-            "stdin_port": ports["stdin"],
-            "control_port": ports["control"],
-            "hb_port": ports["hb"],
+            "shell_port": int(ports["shell"]),
+            "iopub_port": int(ports["iopub"]),
+            "stdin_port": int(ports["stdin"]),
+            "control_port": int(ports["control"]),
+            "hb_port": int(ports["hb"]),
             "ip": self.get_conn_address(),
             "key": self.get_key(),
             "transport": "tcp",
@@ -320,11 +349,11 @@ class DockerKernel:
         :return: Ports.
         """
         ports = {}
-        ports['shell'] = self.plugin.get_option_value('ipython_port_shell')
-        ports['iopub'] = self.plugin.get_option_value('ipython_port_iopub')
-        ports['stdin'] = self.plugin.get_option_value('ipython_port_stdin')
-        ports['control'] = self.plugin.get_option_value('ipython_port_control')
-        ports['hb'] = self.plugin.get_option_value('ipython_port_hb')
+        ports['shell'] = int(self.plugin.get_option_value('ipython_port_shell'))
+        ports['iopub'] = int(self.plugin.get_option_value('ipython_port_iopub'))
+        ports['stdin'] = int(self.plugin.get_option_value('ipython_port_stdin'))
+        ports['control'] = int(self.plugin.get_option_value('ipython_port_control'))
+        ports['hb'] = int(self.plugin.get_option_value('ipython_port_hb'))
         return ports
 
     def get_kernel_file_path(self) -> str:
@@ -341,19 +370,52 @@ class DockerKernel:
 
         :return: Local data directory.
         """
-        return os.path.join(self.plugin.window.core.config.get_user_dir("data"))
+        return str(os.path.join(self.plugin.window.core.config.get_user_dir("data")))
 
-    def execute(self, code: str, current: bool = False) -> str:
+    def check_ready(self):
+        """
+        Check if the IPython kernel is ready.
+
+        :return: True if the kernel is ready, False otherwise.
+        """
+        try:
+            if self.client is not None:
+                self.client.wait_for_ready(timeout=1)
+                return True
+        except Exception as e:
+            self.log(f"Error checking IPython kernel readiness: {e}")
+        return False
+
+    def execute(
+            self,
+            code: str,
+            current: bool = False,
+            auto_init: bool = False) -> str:
         """
         Execute the code in the IPython kernel.
 
         :param code: Python code to execute.
         :param current: Use the current kernel.
+        :param auto_init: Automatically initialize the kernel if not initialized after error.
         :return: Output from the kernel.
         """
-        self.init()
+        self.init(
+            force=False,
+            auto_init=auto_init,
+        )
+        if not self.initialized:
+            self.log("IPython kernel is not initialized.")
+            self.send_output(self.NOT_READY_MSG)
+            return self.NOT_READY_MSG
+
         if not current:
             self.restart_kernel()
+            time.sleep(1)
+
+        if not self.check_ready():
+            self.log("IPython kernel is not ready.")
+            self.send_output(self.NOT_READY_MSG)
+            return self.NOT_READY_MSG
 
         self.log("Executing code: " + str(code)[:100] + "...")
 
@@ -363,11 +425,31 @@ class DockerKernel:
             try:
                 msg = self.client.get_iopub_msg(timeout=1)
             except:
-                continue
+                break
 
             if msg['parent_header'].get('msg_id') != msg_id:
                 continue
 
+            # receive binary image data
+            if msg['msg_type'] in ['display_data', 'execute_result']:
+                data = msg['content'].get('data', {})
+                if 'image/png' in data:
+                    b64_image = data['image/png']
+                    binary_image = base64.b64decode(b64_image)
+                    self.log("Received binary image data.")
+                    if binary_image:
+                        path_to_save = self.plugin.make_temp_file_path('png')
+                        try:
+                            with open(path_to_save, 'wb') as f:
+                                f.write(binary_image)
+                            self.log(f"Image saved to: {path_to_save}")
+                            self.send_output(path_to_save)
+                            return str(path_to_save)
+                        except Exception as e:
+                            self.log(f"Error saving image: {e}")
+                            self.send_output(f"Error saving image: {e}")
+                            return f"Error saving image: {e}"
+
             chunk = str(self.process_message(msg))
             if chunk.strip() != "":
                 output += chunk
@@ -380,22 +462,29 @@ class DockerKernel:
         return self.remove_ansi(output).strip()
 
     def restart_kernel(self) -> bool:
-        """
-        Restart the IPython kernel and reconnect.
+        """Restart kernel"""
+        if self.restarting:
+            self.log("Kernel is already restarting.")
+            return False
 
-        :return: True if the kernel was restarted successfully, False otherwise.
-        """
+        self.restarting = True
         self.send_output("Restarting...")
         self.restart_container(self.get_container_name())
+
         if self.client is not None:
             self.client.stop_channels()
-        else:
-            self.client = BlockingKernelClient(connection_file=self.get_kernel_file_path())
+            try:
+                self.client.close()  # if close() exists
+            except Exception as e:
+                pass
+
+        self.client = BlockingKernelClient(connection_file=self.get_kernel_file_path())
         self.client.load_connection_file()
         self.client.start_channels()
         self.client.wait_for_ready()
         self.log("Connected to IPython kernel.")
         self.send_output("Restarted.")
+        self.restarting = False
         return True
 
     def send_output(self, output: str):
@@ -543,4 +632,5 @@ class DockerKernel:
 
         :param msg: Message to log.
         """
-        print(msg)
\ No newline at end of file
+        print(msg)
+        self.plugin.window.update_status(msg)
\ No newline at end of file
