@@ -8,17 +8,23 @@
 # Created By  : Marcin Szczygliński                  #
 # Updated Date: 2025.07.10 20:00:00                  #
 # ================================================== #
-
+import base64
 import re
+import time
+
 from jupyter_client import KernelManager
 
 class LocalKernel:
+
+    NOT_READY_MSG = "IPython kernel is not initialized... try to restart the kernel with: /restart"
+
     def __init__(self, plugin = None):
         self.plugin = plugin
         self.client = None
         self.manager = None
         self.initialized = False
         self.signals = None
+        self.restarting = False
 
     def restart_kernel(self) -> bool:
         """
@@ -26,6 +32,11 @@ class LocalKernel:
 
         :return: True if successful.
         """
+        if self.restarting:
+            self.log("IPython kernel is already restarting.")
+            return False
+
+        self.restarting = True
         if self.initialized:
             self.client.stop_channels()
             self.manager.restart_kernel(now=True)
@@ -35,6 +46,8 @@ class LocalKernel:
         else:
             self.init()
             self.log("IPython kernel started.")
+        self.client.wait_for_ready()
+        self.restarting = False
         return True
 
     def shutdown_kernel(self):
@@ -95,31 +108,82 @@ class LocalKernel:
         self.client.stop_channels()  # stop the client
         self.manager.shutdown_kernel()
 
-    def execute(self, code: str, current: bool = False) -> str:
+    def check_ready(self):
+        """
+        Check if the IPython kernel is ready.
+
+        :return: True if the kernel is ready, False otherwise.
+        """
+        try:
+            if self.client is not None:
+                self.client.wait_for_ready(timeout=1)
+                return True
+        except Exception as e:
+            self.log(f"Error checking IPython kernel readiness: {e}")
+        return False
+
+    def execute(
+            self,
+            code: str,
+            current: bool = False,
+            auto_init: bool = False
+    ) -> str:
         """
         Execute the code in the IPython kernel.
 
         :param code: Python code to execute.
         :param current: Use the current kernel.
+        :param auto_init: Automatically initialize the kernel if not initialized after error.
         :return: Output from the kernel.
         """
         self.init()
+        if not self.initialized:
+            self.log("IPython kernel is not initialized.")
+            self.send_output(self.NOT_READY_MSG)
+            return self.NOT_READY_MSG
+
         if not current:
             self.restart_kernel()
+            time.sleep(1)
 
         self.log("Executing code: " + str(code)[:100] + "...")
 
+        if not self.check_ready():
+            self.log("IPython kernel is not ready.")
+            self.send_output(self.NOT_READY_MSG)
+            return self.NOT_READY_MSG
+
         msg_id = self.client.execute(code)
         output = ""
         while True:
             try:
                 msg = self.client.get_iopub_msg(timeout=1)
             except:
-                continue
+                break
 
             if msg['parent_header'].get('msg_id') != msg_id:
                 continue
 
+            # receive binary image data
+            if msg['msg_type'] in ['display_data', 'execute_result']:
+                data = msg['content'].get('data', {})
+                if 'image/png' in data:
+                    b64_image = data['image/png']
+                    binary_image = base64.b64decode(b64_image)
+                    self.log("Received binary image data.")
+                    if binary_image:
+                        path_to_save = self.plugin.make_temp_file_path('png')
+                        try:
+                            with open(path_to_save, 'wb') as f:
+                                f.write(binary_image)
+                            self.log(f"Image saved to: {path_to_save}")
+                            self.send_output(path_to_save)
+                            return str(path_to_save)
+                        except Exception as e:
+                            self.log(f"Error saving image: {e}")
+                            self.send_output(f"Error saving image: {e}")
+                            return f"Error saving image: {e}"
+
             chunk = str(self.process_message(msg))
             if chunk.strip() != "":
                 output += chunk
