@@ -6,12 +6,12 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2025.07.26 18:00:00                  #
+# Updated Date: 2025.08.02 20:00:00                  #
 # ================================================== #
 
 from packaging.version import parse as parse_version, Version
 
-from pygpt_net.core.types import MODE_RESEARCH
+from pygpt_net.core.types import MODE_RESEARCH, MODE_CHAT, MODE_AGENT_OPENAI, MODE_COMPUTER, MODE_EXPERT
 
 
 class Patch:
@@ -689,13 +689,35 @@ class Patch:
                 print("Migrating models from < 2.5.71...")
                 updated = True
 
+            # < 2.5.76 <--- add MODE_AGENT_OPENAI
+            if old < parse_version("2.5.76"):
+                print("Migrating models from < 2.5.76...")
+                for id in data:
+                    model = data[id]
+                    if (MODE_CHAT in model.mode or MODE_COMPUTER in model.mode) and MODE_AGENT_OPENAI not in model.mode:
+                        model.mode.append(MODE_AGENT_OPENAI)
+                    if MODE_COMPUTER in model.mode and MODE_AGENT_OPENAI not in model.mode:
+                        model.mode.append(MODE_EXPERT)
+                updated = True
+
+            # < 2.5.81 <--- remove MODE_AGENT_OPENAI from unsupported models
+            if old < parse_version("2.5.81"):
+                print("Migrating models from < 2.5.81...")
+                for id in data:
+                    model = data[id]
+                    if model.provider in ["ollama", "mistral_ai"]:
+                        if "agent_openai" in model.mode:
+                            model.mode.remove("agent_openai")
+                updated = True
+
         # update file
         if updated:
             data = dict(sorted(data.items()))
             self.window.core.models.items = data
             self.window.core.models.save()
 
-            # also patch any missing models
-            self.window.core.models.patch_missing()
+            # also patch any missing models, only if models file is older than 2.5.84
+            if old < parse_version("2.5.84"):
+                self.window.core.models.patch_missing()
 
         return updated
