@@ -6,8 +6,9 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2025.07.09 22:00:00                  #
+# Updated Date: 2025.08.02 20:00:00                  #
 # ================================================== #
+from typing import List, Dict
 
 from pygpt_net.core.types import (
     MODE_LLAMA_INDEX,
@@ -42,3 +43,24 @@ class DeepseekApiLLM(BaseLLM):
         """
         args = self.parse_args(model.llama_index, window)
         return DeepSeek(**args)
+
+    def get_models(
+            self,
+            window,
+    ) -> List[Dict]:
+        """
+        Return list of models for the provider
+
+        :param window: window instance
+        :return: list of models
+        """
+        items = []
+        client = self.get_client(window)
+        models_list = client.models.list()
+        if models_list.data:
+            for item in models_list.data:
+                items.append({
+                    "id": item.id,
+                    "name": item.id,
+                })
+        return items
