@@ -6,7 +6,7 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2025.07.26 18:00:00                  #
+# Updated Date: 2025.08.02 20:00:00                  #
 # ================================================== #
 
 import json
@@ -25,11 +25,7 @@ from llama_index.embeddings.openai import OpenAIEmbedding
 
 from pygpt_net.core.types import (
     MODE_LLAMA_INDEX,
-    OPENAI_REMOTE_TOOL_DISABLE_CODE_INTERPRETER,
-    OPENAI_REMOTE_TOOL_DISABLE_IMAGE,
-    OPENAI_REMOTE_TOOL_DISABLE_WEB_SEARCH,
-    OPENAI_REMOTE_TOOL_DISABLE_FILE_SEARCH,
-    OPENAI_REMOTE_TOOL_DISABLE_MCP,
+    MODE_CHAT,
 )
 from pygpt_net.provider.llms.base import BaseLLM
 from pygpt_net.item.model import ModelItem
@@ -102,45 +98,13 @@ class OpenAILLM(BaseLLM):
 
         if window.core.config.get('api_use_responses_llama', False):
             tools = []
-            if (not model.id.startswith("o1")
-                    and not model.id.startswith("o3")):
-
-                if not model.id in OPENAI_REMOTE_TOOL_DISABLE_WEB_SEARCH:
-                    if window.core.config.get("remote_tools.web_search", False):
-                        tools.append({"type": "web_search_preview"})
-
-                if not model.id in OPENAI_REMOTE_TOOL_DISABLE_CODE_INTERPRETER:
-                    if window.core.config.get("remote_tools.code_interpreter", False):
-                        tools.append({
-                            "type": "code_interpreter",
-                            "container": {
-                                "type": "auto"
-                            }
-                        })
-
-                if not model.id in OPENAI_REMOTE_TOOL_DISABLE_IMAGE:
-                    if window.core.config.get("remote_tools.image", False):
-                        tool = {"type": "image_generation"}
-                        if stream:
-                            tool["partial_images"] = 1  # required for streaming
-                        tools.append(tool)
-
-                if not model.id in OPENAI_REMOTE_TOOL_DISABLE_FILE_SEARCH:
-                    if window.core.config.get("remote_tools.file_search", False):
-                        vector_store_ids = window.core.config.get("remote_tools.file_search.args", "")
-                        if vector_store_ids:
-                            vector_store_ids = [store.strip() for store in vector_store_ids.split(",") if store.strip()]
-                            tools.append({
-                                "type": "file_search",
-                                "vector_store_ids": vector_store_ids,
-                            })
-
-                if not model.id in OPENAI_REMOTE_TOOL_DISABLE_MCP:
-                    if window.core.config.get("remote_tools.mcp", False):
-                        mcp_tool = window.core.config.get("remote_tools.mcp.args", "")
-                        if mcp_tool:
-                            mcp_tool = json.loads(mcp_tool)
-                            tools.append(mcp_tool)
+            tools = window.core.gpt.remote_tools.append_to_tools(
+                mode=MODE_LLAMA_INDEX,
+                model=model,
+                stream=stream,
+                is_expert_call=False,
+                tools=tools,
+            )
             if tools:
                 args["built_in_tools"] = tools
             return LlamaOpenAIResponses(**args)
@@ -184,3 +148,24 @@ class OpenAILLM(BaseLLM):
                 "args": config,
             }, window)
         return OpenAIEmbedding(**args)
+
+    def get_models(
+            self,
+            window,
+    ) -> List[Dict]:
+        """
+        Return list of models for the provider
+
+        :param window: window instance
+        :return: list of models
+        """
+        items = []
+        client = self.get_client(window)
+        models_list = client.models.list()
+        if models_list.data:
+            for item in models_list.data:
+                items.append({
+                    "id": item.id,
+                    "name": item.id,
+                })
+        return items
\ No newline at end of file
