@@ -6,7 +6,7 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2024.04.30 04:00:00                  #
+# Updated Date: 2025.06.29 18:00:00                  #
 # ================================================== #
 
 import copy
@@ -21,6 +21,7 @@ from pygpt_net.ui.widget.element.group import CollapsedGroup
 from pygpt_net.ui.widget.element.labels import UrlLabel
 from pygpt_net.ui.widget.lists.assistant_store import AssistantVectorStoreEditorList
 from pygpt_net.ui.widget.option.checkbox import OptionCheckbox
+from pygpt_net.ui.widget.option.checkbox_list import OptionCheckboxList
 from pygpt_net.ui.widget.option.combo import OptionCombo
 from pygpt_net.ui.widget.option.dictionary import OptionDict
 from pygpt_net.ui.widget.option.input import OptionInput, PasswordInput
@@ -383,6 +384,9 @@ class AssistantVectorStore:
                 widgets[key] = OptionTextarea(self.window, parent, key, option)  # textarea
             elif option['type'] == 'bool':
                 widgets[key] = OptionCheckbox(self.window, parent, key, option)  # checkbox
+            elif option['type'] == 'bool_list':
+                self.window.controller.config.placeholder.apply(option)
+                widgets[key] = OptionCheckboxList(self.window, parent, key, option)  # checkbox list
             elif option['type'] == 'dict':
                 self.window.controller.config.placeholder.apply(option)
                 widgets[key] = OptionDict(self.window, parent, key, option)  # dictionary
